@@ -14,7 +14,7 @@ BEGIN{
 		$HUF = 'Hash::Util::FieldHash::Compat';
 	}
 
-	$HUF->import(qw(fieldhash));
+	$HUF->import(qw(fieldhash id));
 }
 
 printf "Perl %vd on $^O\n", $^V;
@@ -25,11 +25,9 @@ print "Hash::FieldHash ", Hash::FieldHash->VERSION, "\n";
 fieldhash my %huf;
 Hash::FieldHash::fieldhash my %hf;
 
-my %hash;
-
 cmpthese timethese -1 => {
 	'H::U::F' => sub{
-		my $o = {};
+		my $o = bless {};
 		for(1 .. 10){
 			$huf{$o} = $_;
 			$huf{$o} = $huf{$o} + $huf{$o} + $huf{$o};
@@ -37,7 +35,7 @@ cmpthese timethese -1 => {
 		}
 	},
 	'H::F' => sub{
-		my $o = {};
+		my $o = bless {};
 		for(1 .. 10){
 			$hf{$o} = $_;
 			$hf{$o} = $hf{$o} + $hf{$o} + $hf{$o};
@@ -45,11 +43,11 @@ cmpthese timethese -1 => {
 		}
 	},
 	'normal' => sub{
-		my $o = {};
+		my $o = bless {};
 		for(1 .. 10){
-			$hash{$o} = $_;
-			$hash{$o} = $hash{$o} + $hash{$o} + $hash{$o};
-			$hash{$o} == ($_*3) or die $hash{$o};
+			$o->{value} = $_;
+			$o->{value} = $o->{value} + $o->{value} + $o->{value};
+			$o->{value} == ($_*3) or die $o->{value};
 		}
 	},
 	
